@@ -2,7 +2,7 @@
  *  Copyright (C) 1999 Olivier Fourdan (fourdan@xfce.org)
  *                2002 Xavier MAILLARD (zedek@fxgsproject.org)
  *                2003 Jasper Huijsmans (huysmans@users.sourceforge.net)
- *                2003 Benedikt Meurer (benedikt.meurer@unix-ag.uni-siegen.de)
+ *                2003,2004 Benedikt Meurer (benny@xfce.org)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,11 +41,9 @@
 #include <libgtkhtml/gtkhtml.h>
 #endif
 
-#include <libxfce4util/i18n.h>
+#include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 
-#include "xfce-logo-icon.h"
-
 #define SEARCHPATH	(DATADIR G_DIR_SEPARATOR_S "%F.%L:"	\
                          DATADIR G_DIR_SEPARATOR_S "%F.%l:"	\
                          DATADIR G_DIR_SEPARATOR_S "%F")
@@ -64,7 +62,7 @@ static GtkWidget *info;
 static void
 info_help_cb (GtkWidget * w, gpointer data)
 {
-    exec_command ("xfhelp4");
+    xfce_exec ("xfhelp4", FALSE, FALSE, NULL);
 }
 
 #ifdef HAVE_LIBGTKHTML
@@ -87,10 +85,43 @@ link_clicked (HtmlDocument * htmldoc, const gchar * url, gpointer data)
 	g_snprintf (command, sizeof (command),
 		    "ns-remote -remote \"openURL(%s)\"", url);
 
-    exec_command (command);
+    xfce_exec (command, FALSE, FALSE, NULL);
 }
 #endif
 
+static gchar*
+replace_version (gchar *buffer)
+{
+    gchar *dst;
+    gchar *bp;
+
+    bp = strstr (buffer, "@VERSION@");
+    if (bp != NULL)
+    {
+        const gchar *version = xfce_version_string ();
+        gchar *complete_version;
+        gsize n = bp - buffer;
+        
+#ifdef RELEASE_LABEL
+        if (strlen (RELEASE_LABEL))
+            complete_version = g_strdup_printf ("%s (%s)", version, RELEASE_LABEL);
+        else
+#endif
+            complete_version = g_strdup (version);
+
+        dst = g_new (gchar, strlen (buffer) + strlen (complete_version) + 1);
+        memcpy (dst, buffer, n);
+        memcpy (dst + n, complete_version, strlen (complete_version));
+        strcpy (dst + n + strlen (complete_version), buffer + n + strlen ("@VERSION@"));
+        g_free (complete_version);
+        g_free (buffer);
+        
+        return dst;
+    }
+
+    return buffer;
+}
+
 static void
 add_page (GtkNotebook * notebook, const gchar * name, const gchar * filename,
 	  gboolean hscrolling)
@@ -99,7 +130,7 @@ add_page (GtkNotebook * notebook, const gchar * name, const gchar * filename,
     HtmlDocument *htmldoc;
     gboolean usehtml;
 #endif
-    gchar buffer[PATH_MAX + 1];
+    /*gchar buffer[PATH_MAX + 1];*/
     GtkTextBuffer *textbuffer;
     GtkWidget *textview;
     GtkWidget *label;
@@ -144,67 +175,70 @@ add_page (GtkNotebook * notebook, const gchar * name, const gchar * filename,
     }
 #endif
 
-    g_file_get_contents (path, &buf, &n, &err);
-    g_free (path);
+    if (g_file_get_contents (path, &buf, &n, &err))
+    {
+        buf = replace_version (buf);
+        g_free (path);
+    }
 
     if (err != NULL)
     {
-	xfce_err ("%s", err->message);
-	g_error_free (err);
+        xfce_err ("%s", err->message);
+        g_error_free (err);
     }
     else
     {
-	view = gtk_frame_new (NULL);
-	gtk_container_set_border_width (GTK_CONTAINER (view), BORDER);
-	gtk_frame_set_shadow_type (GTK_FRAME (view), GTK_SHADOW_IN);
-	gtk_widget_show (view);
+        view = gtk_frame_new (NULL);
+        gtk_container_set_border_width (GTK_CONTAINER (view), BORDER);
+        gtk_frame_set_shadow_type (GTK_FRAME (view), GTK_SHADOW_IN);
+        gtk_widget_show (view);
 
-	sw = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-					hscrolling ? GTK_POLICY_AUTOMATIC :
-					GTK_POLICY_NEVER,
-					GTK_POLICY_AUTOMATIC);
-	gtk_widget_show (sw);
-	gtk_container_add (GTK_CONTAINER (view), sw);
+        sw = gtk_scrolled_window_new (NULL, NULL);
+        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+                hscrolling ? GTK_POLICY_AUTOMATIC :
+                GTK_POLICY_NEVER,
+                GTK_POLICY_AUTOMATIC);
+        gtk_widget_show (sw);
+        gtk_container_add (GTK_CONTAINER (view), sw);
 
 #ifdef HAVE_LIBGTKHTML
-	if (usehtml)
-	{
-	    htmldoc = html_document_new ();
-	    html_document_open_stream (htmldoc, "text/html");
-	    html_document_write_stream (htmldoc, buf, n);
-	    html_document_close_stream (htmldoc);
+        if (usehtml)
+        {
+            htmldoc = html_document_new ();
+            html_document_open_stream (htmldoc, "text/html");
+            html_document_write_stream (htmldoc, buf, strlen (buf));
+            html_document_close_stream (htmldoc);
 
-	    textview = html_view_new ();
-	    html_view_set_document (HTML_VIEW (textview), htmldoc);
+            textview = html_view_new ();
+            html_view_set_document (HTML_VIEW (textview), htmldoc);
 
-	    /* connect callbacks */
-	    g_signal_connect (G_OBJECT (htmldoc), "link_clicked",
-			      G_CALLBACK (link_clicked), NULL);
+            /* connect callbacks */
+            g_signal_connect (G_OBJECT (htmldoc), "link_clicked",
+                  G_CALLBACK (link_clicked), NULL);
 
-	    /* resize window */
-	    gtk_window_set_default_size (GTK_WINDOW (info), 615, 530);
-	}
-	else
-	{
+            /* resize window */
+            gtk_window_set_default_size (GTK_WINDOW (info), 615, 530);
+        }
+        else
+        {
 #endif
-	    textbuffer = gtk_text_buffer_new (NULL);
-	    gtk_text_buffer_set_text (textbuffer, buf, n);
+            textbuffer = gtk_text_buffer_new (NULL);
+            gtk_text_buffer_set_text (textbuffer, buf, strlen (buf));
 
-	    textview = gtk_text_view_new_with_buffer (textbuffer);
-	    gtk_text_view_set_editable (GTK_TEXT_VIEW (textview), FALSE);
-	    gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview), BORDER);
-	    gtk_text_view_set_right_margin (GTK_TEXT_VIEW (textview), BORDER);
+            textview = gtk_text_view_new_with_buffer (textbuffer);
+            gtk_text_view_set_editable (GTK_TEXT_VIEW (textview), FALSE);
+            gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview), BORDER);
+            gtk_text_view_set_right_margin (GTK_TEXT_VIEW (textview), BORDER);
 #ifdef HAVE_LIBGTKHTML
-	}
+        }
 #endif
 
-	gtk_widget_show (textview);
-	gtk_container_add (GTK_CONTAINER (sw), textview);
+        gtk_widget_show (textview);
+        gtk_container_add (GTK_CONTAINER (sw), textview);
 
-	gtk_notebook_append_page (notebook, view, label);
+        gtk_notebook_append_page (notebook, view, label);
 
-	g_free (buf);
+        g_free (buf);
     }
 }
 
@@ -225,11 +259,11 @@ main (int argc, char **argv)
     gtk_init (&argc, &argv);
 
     info = gtk_dialog_new ();
-    gtk_window_set_title (GTK_WINDOW (info), _("About XFce 4"));
+    gtk_window_set_title (GTK_WINDOW (info), _("About Xfce 4"));
     gtk_dialog_set_has_separator (GTK_DIALOG (info), FALSE);
     gtk_window_stick (GTK_WINDOW (info));
 
-    logo_pb = inline_icon_at_size (xfce_logo_data, 48, 48);
+    logo_pb = xfce_themed_icon_load ("xfce4-logo", 48);
     gtk_window_set_icon (GTK_WINDOW (info), logo_pb);
 
     vbox2 = gtk_vbox_new (FALSE, 0);
@@ -240,9 +274,9 @@ main (int argc, char **argv)
     text =
 	g_strdup_printf
 	("%s\n<span size=\"smaller\" style=\"italic\">%s</span>",
-	 _("XFce Desktop Environment"),
-	 _("Copyright 2002-2003 by Olivier Fourdan"));
-    header = create_header (logo_pb, text);
+	 _("Xfce Desktop Environment"),
+	 _("Copyright 2002-2004 by Olivier Fourdan"));
+    header = xfce_create_header (logo_pb, text);
     gtk_widget_show (header);
     gtk_box_pack_start (GTK_BOX (vbox2), header, FALSE, FALSE, 0);
     g_free (text);
@@ -256,10 +290,13 @@ main (int argc, char **argv)
     /* the notebook */
     notebook = gtk_notebook_new ();
     gtk_widget_show (notebook);
-    gtk_widget_set_size_request (notebook, -1, 300);
+    gtk_widget_set_size_request (notebook, -1, 270);
     gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
 
     /* add pages */
+#ifdef VENDOR_INFO
+    add_page (GTK_NOTEBOOK (notebook), VENDOR_INFO, VENDOR_INFO, FALSE);
+#endif
     add_page (GTK_NOTEBOOK (notebook), _("Info"), XFCE_INFO, FALSE);
     add_page (GTK_NOTEBOOK (notebook), _("Credits"), XFCE_AUTHORS, FALSE);
     add_page (GTK_NOTEBOOK (notebook), _("Copyright"), XFCE_COPYRIGHT, TRUE);
@@ -272,8 +309,7 @@ main (int argc, char **argv)
 
     info_help_button = gtk_button_new_from_stock (GTK_STOCK_HELP);
     gtk_widget_show (info_help_button);
-    gtk_box_pack_start (GTK_BOX (buttonbox), info_help_button, FALSE, FALSE,
-			0);
+    gtk_box_pack_start (GTK_BOX (buttonbox), info_help_button, FALSE, FALSE, 0);
 
     info_ok_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
     gtk_widget_show (info_ok_button);
@@ -290,7 +326,7 @@ main (int argc, char **argv)
     g_signal_connect (info_help_button, "clicked",
 		      G_CALLBACK (info_help_cb), NULL);
 
-    gtk_window_set_position (GTK_WINDOW (info), GTK_WIN_POS_CENTER);
+    xfce_gtk_window_center_on_monitor_with_pointer (GTK_WINDOW (info));
     gtk_widget_show (info);
 
     gtk_main ();
